# Generated by Django 2.2.11 on 2020-03-05 18:46

import django.core.validators
from django.db import migrations, models
import image_cropping.fields
import socialprofile.models


class Migration(migrations.Migration):

    dependencies = [
        ('socialprofile', '0003_merge_20200207_1147'),
    ]

    operations = [
        migrations.AddField(
            model_name='socialprofile',
            name='address',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='Address'),
        ),
        migrations.AddField(
            model_name='socialprofile',
            name='city',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='City'),
        ),
        migrations.AddField(
            model_name='socialprofile',
            name='company',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='Company'),
        ),
        migrations.AddField(
            model_name='socialprofile',
            name='last_accessed',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='socialprofile',
            name='postalcode',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='Postal Code'),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='country',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='Country'),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='date_of_birth',
            field=models.DateField(blank=True, null=True, verbose_name='Date of Birth'),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='description',
            field=models.TextField(blank=True, help_text='Tell us about yourself!', null=True, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='editByGoogle',
            field=models.NullBooleanField(default=False, verbose_name="Google Edit User's Info"),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='email',
            field=models.EmailField(max_length=254, verbose_name='Email Address'),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='function_01',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='function_02',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='function_03',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='function_04',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='function_05',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='function_06',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='function_07',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='function_08',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='function_09',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='function_10',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='gender',
            field=models.CharField(blank=True, choices=[('male', 'Male'), ('female', 'Female'), ('other', 'Other'), ('', '')], max_length=10, null=True, verbose_name='Gender'),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='google_circledByCount',
            field=models.IntegerField(blank=True, default=0, null=True, verbose_name='Google Circle byCount'),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='google_isPlusUser',
            field=models.NullBooleanField(default=False, verbose_name='Google Plus'),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='google_kind',
            field=models.CharField(blank=True, max_length=2, null=True, verbose_name='Google Kind'),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='google_language',
            field=models.CharField(blank=True, max_length=2, null=True, verbose_name='Google Language'),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='google_plusUrl',
            field=models.URLField(blank=True, max_length=500, null=True, verbose_name='Google Plus Page'),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='google_verified',
            field=models.NullBooleanField(default=False, verbose_name='Google Verified'),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='image',
            field=image_cropping.fields.ImageCropField(blank=True, null=True, upload_to='user/'),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='image_url',
            field=models.URLField(blank=True, max_length=500, null=True, verbose_name='Avatar Picture'),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='is_active',
            field=models.NullBooleanField(default=True, help_text='Designates whether this user should be treated as active. Unselect this instead of deleting accounts.', verbose_name='active'),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='is_staff',
            field=models.NullBooleanField(default=False, help_text='Designates whether the user can log into this admin site.', verbose_name='staff status'),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='manually_edited',
            field=models.NullBooleanField(default=False, verbose_name='Manually Edited'),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='phone_number',
            field=models.CharField(blank=True, max_length=16, null=True, validators=[django.core.validators.RegexValidator(message="Phone number must be entered in the format: '+999999999'. Up to 15 digits allowed.", regex='^\\+\\d{8,15}$')]),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='role',
            field=models.CharField(blank=True, max_length=500, null=True, verbose_name='Role'),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='sort',
            field=socialprofile.models.IntegerRangeField(blank=True, default=1, null=True, verbose_name='Sort Order'),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='title',
            field=models.CharField(blank=True, default='Member', max_length=500, null=True, verbose_name='Title'),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='url',
            field=models.URLField(blank=True, help_text='Where can we find out more about you?', max_length=500, null=True, verbose_name='Homepage'),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='username',
            field=models.CharField(error_messages={'unique': 'A user with that username already exists.'}, help_text='Required. 30 characters or fewer. Letters, digits and @/./+/-/_ only.', max_length=30, unique=True, validators=[django.core.validators.RegexValidator('^[\\w.@+-]+$', 'Enter a valid username. This value may contain only letters, numbers and @/./+/-/_ characters.')], verbose_name='Username'),
        ),
        migrations.AlterField(
            model_name='socialprofile',
            name='visible',
            field=models.NullBooleanField(default=False, help_text='Designates whether this user should be visible by all. Unselect this make your account private!', verbose_name='Visible in the Public Pages'),
        ),
    ]



"""Django forms for the socialprofile application"""
from django import forms
from django.utils.html import strip_tags
from .models import SocialProfile
import logging

from crispy_forms.helper import FormHelper
from crispy_forms.layout import Layout, Submit, Row, Column

# from django.conf import settings
# from django.core.exceptions import ObjectDoesNotExist
# from django.utils.translation import ugettext_lazy as _
# from widgets import H5EmailInput
# from image_cropping import ImageCropWidget


# pylint: disable=E1120,W0212

LOGGER = logging.getLogger(name='socialprofile.forms')


class SocialProfileForm(forms.ModelForm):
    """Master form for editing the user's profile"""

    # user = forms.IntegerField(widget=forms.HiddenInput, required=True)
    returnTo = forms.CharField(widget=forms.HiddenInput, required=False, initial='/')  # URI to Return to after save
    manually_edited = forms.BooleanField(widget=forms.HiddenInput, required=False, initial=True)

    class Meta(object):
        """Configuration for the ModelForm"""
        model = SocialProfile
        fields = ['username',
                  'first_name', 'last_name', 'email', 'gender',
                  'url', 'image_url', 'description',
                  'cropping', 'cropping_free',
                  'country', 'city', 'address', 'postalcode',
                  'company', 'visible', 'sort', 'title', 'role',
                  'function_01', 'function_02', 'function_03', 'function_04', 'function_05', 'function_06',
                  'function_07', 'function_08', 'function_09', 'function_10']

    # Don't let through for security reasons, user should be based on logged in user only
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.helper = FormHelper()
        self.helper.layout = Layout(
            Row(
                Column('email', css_class='form-group col-md-6 mb-0'),
                css_class='form-row'
            ),
            Row(
                Column('first_name', css_class='form-group col-md-6 mb-0'),
                Column('last_name', css_class='form-group col-md-4 mb-0'),
                Column('gender', css_class='form-group col-md-2 mb-0'),
                css_class='form-row'
            ),
            Row(
                Column('url', css_class='form-group col-md-6 mb-0'),
                Column('image_url', css_class='form-group col-md-6 mb-0'),
                css_class='form-row'
            ),
            Row(
                Column('address', css_class='form-group col-md-6 mb-0'),
                css_class='form-row'
            ),
            Row(
                Column('country', css_class='form-group col-md-6 mb-0'),
                Column('city', css_class='form-group col-md-4 mb-0'),
                Column('postalcode', css_class='form-group col-md-2 mb-0'),
                css_class='form-row'
            ),
            Submit('submit', 'Save')
        )

    def clean_description(self):
        """Automatically called by Django, this method 'cleans' the description, e.g. stripping HTML out of desc"""

        LOGGER.debug("socialprofile.forms.SocialProfileForm.clean_description")

        return strip_tags(self.cleaned_data['description'])

    def clean(self):
        """Automatically called by Django, this method 'cleans' the whole form"""

        LOGGER.debug("socialprofile.forms.SocialProfileForm.clean")

        if self.changed_data:
            self.cleaned_data['manually_edited'] = True



"""
    Master URL Pattern List for the application.  Most of the patterns here should be top-level
    pass-offs to sub-modules, who will have their own urls.py defining actions within.
"""

# pylint: disable=W0401, W0614, E1120

from django.conf.urls import url, include
from django.views.decorators.cache import never_cache
from django.contrib.auth.decorators import login_required
from django.contrib.auth import logout

from . import views

from rest_framework_jwt.views import obtain_jwt_token, refresh_jwt_token, verify_jwt_token

urlpatterns = [
    # Profile Self View
    url(r'^$', never_cache(login_required(views.SocialProfileView.as_view())), name="sp_profile_view_page"),
    url(r'^login/$', never_cache(login_required(views.home))),
    url(r'^logout/$', never_cache(views.logout), name="sp_logout_page"),
    url(r'^done/$', views.done, name='done'),
    # url(r'^ajax-auth/(?P<backend>[^/]+)/$', views.ajax_auth, name='ajax-auth'),

    # New Profile
    url(r'^new-profile/$', login_required(views.SocialProfileWelcome.as_view()), name="new_profile"),
    # New Profile's Association
    url(r'^new-association/$', login_required(views.SocialProfileView.as_view()), name="new_profile_association"),
    # Login Error
    url(r'^login-error/$', login_required(views.SocialProfileView.as_view()), name="login_error"),
    # Login Error
    url(r'^inactive/$', login_required(views.SocialProfileView.as_view()), name="inactive"),
    # Profile Disconnected
    url(r'^profile-disconnected/$', login_required(views.SocialProfileView.as_view()), name="profile_disconnected"),

    # Profile Other View
    url(r'^view/(?P<username>\w.+)/$', login_required(views.SocialProfileView.as_view()),
        name="sp_profile_other_view_page"),

    # Profile Edit
    url(r'^edit/(?P<user_id>\d+)/$', never_cache(login_required(views.SocialProfileEditView.as_view())), name="sp_profile_edit_page"),

    # Select Sign Up Method
    url(r'^select/$', never_cache(views.SelectAuthView.as_view()), name="sp_select_page"),

    # Delete
    url(r'^delete/$', login_required(views.DeleteSocialProfileView.as_view()), name="sp_delete_page"),

    # Logout Page
    # url(r'^logout/$', logout, name="sp_logout_page"),

    # Social Auth
    url(r'', include('social_django.urls', namespace='social')),

    # User Sessions
    url(r'', include('user_sessions.urls', 'user_sessions')),

    # OAuth2 Token
    url(r'^o/', include('oauth2_provider.urls', namespace='oauth2_provider')),

    # Rest Framework
    url(r'^api-auth/', include('rest_framework.urls', namespace='rest_framework')),
    url(r'^api-token-auth/', obtain_jwt_token),
    url(r'^api-token-refresh/', refresh_jwt_token),
    url(r'^api-token-verify/', verify_jwt_token),

    # One-Time-Password
    # url(r'', include('two_factor.urls', 'two_factor')),

]
